@@ -11,7 +11,9 @@ factory_huxtable <- function(tab,
                              ...) {
 
 
-  assert_dependency("huxtable")
+  insight::check_if_installed("huxtable")
+
+  colnames(tab) <- gsub("\\|\\|\\|\\|", " / ", colnames(tab))
 
   ## warning on align
   # if (!is.null(align)) {
