@@ -11,7 +11,7 @@ expect_snapshot_print(
   "datasummary_balance-escape_TRUE")
 expect_snapshot_print(
   datasummary_balance(~vs, data = dat, output = "latex", escape = FALSE),
-  "datasummary_balance-escape_TRUE")
+  "datasummary_balance-escape_FALSE")
 
 # stub is escaped in latex
 tmp <- data.frame(
@@ -65,10 +65,12 @@ tab <- datasummary_balance(~vs, dat, output="dataframe")
 expect_equivalent(tab[[4]][1:2], c("5.6", "16.7"))
 
 # palmer penguins was once broken with kableExtra
+options(modelsummary_factory_html = "kableExtra")
 penguins <- "https://vincentarelbundock.github.io/Rdatasets/csv/palmerpenguins/penguins.csv"
 penguins <- read.csv(penguins)
 raw <- datasummary_balance(~sex, penguins, output = "html", dinm = FALSE)
 expect_inherits(raw, "knitr_kable")
+options(modelsummary_factory_html = NULL)
 
 # variable name with spaces
 tmp <- mtcars
@@ -299,4 +301,29 @@ expect_equivalent(tab[1, 3], '0.6')
 expect_equivalent(tab[1, 4], '4.7')
 expect_equivalent(tab[1, 5], '0.8')
 expect_equivalent(tab[1, 6], '5.5')
-expect_equivalent(tab[1, 7], '0.4')
\ No newline at end of file
+expect_equivalent(tab[1, 7], '0.4')
+
+# Issue #711: stars and d-columns
+requiet("dplyr")
+training <- 'https://vincentarelbundock.github.io/Rdatasets/csv/Ecdat/Treatment.csv'
+training <- read.csv(training, na.strings = "")
+training <- training %>%
+  dplyr::mutate(`Earnings Before` = re75 / 1000,
+         `Earnings After` = re78 / 1000,
+         Treatment = ifelse(treat == TRUE, 'Treatment', 'Control'),
+         Married = ifelse(married == TRUE, 'Yes', 'No')) %>%
+  dplyr::select(`Earnings Before`,
+         `Earnings After`,
+         Treatment,
+         Ethnicity = ethn,
+         Age = age,
+         Education = educ,
+         Married)
+tab <- datasummary_balance(~ Treatment, training, fmt = 3, stars = TRUE, align = "lllllldl", output = "latex")
+expect_snapshot_print(tab, "datasummary_balance-issue711")
+
+
+# Issue #751
+tab <- datasummary_balance(mpg + hp ~ am, data = mtcars, output = "dataframe")
+expect_equal(nrow(tab), 2)
+
